==> mod_uploader-2.6.0.tgz: mod_uploader-2.6.0/src/CGIRFC2822Parser.cpp <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: CGIRFC2822Parser.cpp 2500 2007-07-06 15:06:45Z svn $
 *****************************************************************************/

#include "CGIRFC2822Parser.h"

#include "Environment.h"

#include "SourceInfo.h"
#define TEMPLATE_INSTANTIATION
#include "BasicFileWriter.cpp"
#include "Base64FileWriter.cpp"
#include "MultipartMessageParser.cpp"
#include "RFC2822Parser.cpp"

SOURCE_INFO_ADD("$Id: CGIRFC2822Parser.cpp 2500 2007-07-06 15:06:45Z svn $");

template class Base64FileWriter<BasicFileWriter>;
template class MultipartMessageParser<CGIRequestReader, Base64FileWriter<BasicFileWriter> >;
template class RFC2822Parser<CGIRequestReader>;

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:

==> mod_uploader-2.6.3.tgz: mod_uploader-2.6.3/src/CGIRFC2822Parser.cpp <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: CGIRFC2822Parser.cpp 2696 2007-11-18 14:46:40Z svn $
 *****************************************************************************/

#include "CGIRFC2822Parser.h"

#include "Environment.h"

#include "SourceInfo.h"
#define TEMPLATE_INSTANTIATION
#include "Base64FileWriter.cpp"
#include "MultipartMessageParser.cpp"
#include "RFC2822Parser.cpp"

SOURCE_INFO_ADD("$Id: CGIRFC2822Parser.cpp 2696 2007-11-18 14:46:40Z svn $");

template class Base64FileWriter<>;
template class MultipartMessageParser<CGIRequestReader, Base64FileWriter<> >;
template class RFC2822Parser<CGIRequestReader>;

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
